/**
  ******************************************************************************
  * @file    stm32l0xx_lppuart_configuration.h
  * @author  MCD Application Team
  * @version V1.0.0
  * @date    01-October-2014
  * @brief   Header for stm32xx_lppuart.c module
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; COPYRIGHT(c) 2014 STMicroelectronics</center></h2>
  *
  * Redistribution and use in source and binary forms, with or without modification,
  * are permitted provided that the following conditions are met:
  *   1. Redistributions of source code must retain the above copyright notice,
  *      this list of conditions and the following disclaimer.
  *   2. Redistributions in binary form must reproduce the above copyright notice,
  *      this list of conditions and the following disclaimer in the documentation
  *      and/or other materials provided with the distribution.
  *   3. Neither the name of STMicroelectronics nor the names of its contributors
  *      may be used to endorse or promote products derived from this software
  *      without specific prior written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
  * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
  * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
  * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
  * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
  * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
  * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  ******************************************************************************
  */

 /**
  *	This file contains the full configuration of the UART available to the user.
  *	The configuration supported is depending on the MCU used. Please refer to the relevant datasheet.
  *	This file is making easier the UART configuration. It is given as input to the file stm32L0xx_lppuart_driver_definition.h
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __STM32XX_LPPUART_CONFIGURATION_H
#define __STM32XX_LPPUART_CONFIGURATION_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "stm32xx_lppuart_conf.h"

/* Exported types ------------------------------------------------------------*/
/* Build definition defines --------------------------------------------------------*/
 /*
  * THIS SECTION SHOULD NOT BE MODIFIED
  */
 #define BLE_ON_USART1		1
 #define BLE_ON_USART2		2
 #define BLE_ON_LPUART		3

 #define DMA1_CHANNEL2		1
 #define DMA1_CHANNEL3		2
 #define DMA1_CHANNEL4		3
 #define DMA1_CHANNEL5		4
 #define DMA1_CHANNEL6		5
 #define DMA1_CHANNEL7		6

 #define	PA0				1		/*<< USART2_CTS */
 #define	PA1				2		/*<< USART2_RTS */
 #define	PA2				3		/*<< USART2_TX */
 #define	PA3				4		/*<< USART2_RX */
 #define	PA6				5		/*<< LPUART_CTS */
 #define	PA9				6		/*<< USART1_TX */
 #define	PA10			7		/*<< USART1_RX */
 #define	PA11			8		/*<< USART1_CTS */
 #define	PA12			9		/*<< USART1_RTS */
 #define	PA14			10		/*<< USART2_TX */
 #define	PA15			11		/*<< USART2_RX */
 #define	PB6				12		/*<< USART1_TX */
 #define	PB7				13		/*<< USART1_RX */
 #define	PB10			14		/*<< LPUART_TX */
 #define	PB11			15		/*<< LPUART_RX */
 #define	PB13			16		/*<< LPUART_CTS */
 #define	PB14			17		/*<< LPUART_RTS */
 #define	PC4				18		/*<< LPUART_TX */
 #define	PC5				19		/*<< LPUART_RX */
 #define	PC10			20		/*<< LPUART_TX */
 #define	PC11			21		/*<< LPUART_RX */
 #define	PD2				22		/*<< LPUART_RTS */

/* Exported defines --------------------------------------------------------*/
 /*
  * THIS SECTION NEED TO BE UPDATED ACCORDING TO THE SETUP
  */

 /**
  *  USART baudrate selection
  *  The baudrate shall be identical to the connectivity device
  */
#define	USART_BAUDRATE	((uint32_t)1000000)

 /**
  *  USART selection
   *  The selection shall be either:
  *  BLE_ON_USART1
  *  BLE_ON_USART2
  *  BLE_ON_LPUART
  */
#define USART_SELECTED 	BLE_ON_USART2

 /**
  *  USART TX pin selection
  *  The selection shall be either:
  *  For USART1: PA9, PB6
  *  For USART2: PA2, PA14
  *  For LPUART: PB10, PC4, PC10
  */
#define USART_TX_PIN_SELECTED	PA2

 /**
  *  USART RX pin selection
  *  The selection shall be either:
  *  For USART1: PA10, PB7
  *  For USART2: PA3, PA15
  *  For LPUART: PB11, PC5, PC11
  */
#define USART_RX_PIN_SELECTED	PA3

 /**
  *  USART RTS pin selection
  *  The selection shall be either:
  *  For USART1: PA12
  *  For USART2: PA1
  *  For LPUART: PB14, PD2
  */
#define USART_RTS_PIN_SELECTED	PA1

 /**
  *  USART CTS pin selection
  *  The selection shall be either:
  *  For USART1: PA11
  *  For USART2: PA0
  *  For LPUART: PA6, PB13
  */
#define USART_CTS_PIN_SELECTED	PA0

 /**
  *  USART TX DMA Channel Selection
  *  The selection shall be either:
  *  For USART1: DMA1_CHANNEL4, DMA1_CHANNEL2
  *  For USART2: DMA1_CHANNEL7, DMA1_CHANNEL4
  *  For LPUART: DMA1_CHANNEL7, DMA1_CHANNEL2
  */
#define USART_TX_DMA_CHANNEL_SELECTED	DMA1_CHANNEL7

 /**
  *  USART RX DMA Channel Selection
  *  The selection shall be either:
  *  For USART1: DMA1_CHANNEL5, DMA1_CHANNEL3
  *  For USART2: DMA1_CHANNEL6, DMA1_CHANNEL5
  *  For LPUART: DMA1_CHANNEL6, DMA1_CHANNEL3
  */
#define USART_RX_DMA_CHANNEL_SELECTED	DMA1_CHANNEL6

 /**
  *  Define a critical section in the Low Power UART driver
  *  The default implementations is masking all interrupts using the PRIMASK bit
  *  When the application is implementing low latency interrupts that would not impact the system (only FW processing),
  *  the critical section may use the basepri register to mask out only interrupt that would impact the system
  *  This would keep the low latency interrupt with higher priority enable
  */
#define LPPUART_ENTER_CRITICAL_SECTION	__disable_irq()	/**< Enter the critical section */
#define LPPUART_EXIT_CRITICAL_SECTION	__enable_irq()	/**< Exit the critical section */


 /**
  * Preempt priority configuration
  * These are the interrupt priority settings of the 3 hardware resources used when transferring data over UART
  * The priority and the order may be changed by the user
  */
#define	NVIC_UART_DMA_IT_PREEMPTPRIORITY		0
#define	NVIC_UART_UART_IT_PREEMPTPRIORITY		1
#define	NVIC_UART_WCTS_IT_PREEMPTPRIORITY		2

 /**
  * Sub priority configuration - NOT SUPPORTED ON STM32L0xx
  * These are the interrupt priority settings of the 3 hardware resources used when transferring data over UART
  * The priority and the order may be changed by the user
  */
#define	NVIC_UART_DMA_IT_SUBPRIORITY		0
#define	NVIC_UART_UART_IT_SUBPRIORITY		0
#define	NVIC_UART_WCTS_IT_SUBPRIORITY		0

 /* Exported constants --------------------------------------------------------*/
/* Exported macros -----------------------------------------------------------*/
/* Exported functions ------------------------------------------------------- */ 

#ifdef __cplusplus
}
#endif

#endif /*__STM32XX_LPPUART_CONFIGURATION_H */

/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
