/**
  ******************************************************************************
  * @file    wavetek_nRF_conf.h
  * @author  MCD Application Team
  * @version V1.0.0
  * @date    01-October-2014
  * @brief   Configuration file for the wavetek_nRF.c module
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; COPYRIGHT(c) 2014 STMicroelectronics</center></h2>
  *
  * Redistribution and use in source and binary forms, with or without modification,
  * are permitted provided that the following conditions are met:
  *   1. Redistributions of source code must retain the above copyright notice,
  *      this list of conditions and the following disclaimer.
  *   2. Redistributions in binary form must reproduce the above copyright notice,
  *      this list of conditions and the following disclaimer in the documentation
  *      and/or other materials provided with the distribution.
  *   3. Neither the name of STMicroelectronics nor the names of its contributors
  *      may be used to endorse or promote products derived from this software
  *      without specific prior written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
  * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
  * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
  * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
  * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
  * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
  * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  ******************************************************************************
  */

#ifndef __WAVETEK_NRF_CONF_H
#define __WAVETEK_NRF_CONF_H

#ifdef __cplusplus
 extern "C" {
#endif

 /* Includes ------------------------------------------------------------------*/
#include "stm32l0xx_hal.h"
#include "wavetek_nRF.h"

 /* Exported defines --------------------------------------------------------*/
 /**
  * Fixed configuration
  */
 #define WAVETEK_NRF_LED1_GPIO_PORT		GPIOB
 #define WAVETEK_NRF_LED2_GPIO_PORT		GPIOB
 #define WAVETEK_NRF_LED3_GPIO_PORT		GPIOA
 #define WAVETEK_NRF_LED1_PIN			GPIO_PIN_5
 #define WAVETEK_NRF_LED2_PIN			GPIO_PIN_3
 #define WAVETEK_NRF_LED3_PIN			GPIO_PIN_10

 /**
  * Fixed configuration
  */
 #define WAVETEK_NRF_BUTTON1_GPIO_PORT		GPIOA
 #define WAVETEK_NRF_BUTTON2_GPIO_PORT		GPIOA
 #define WAVETEK_NRF_BUTTON3_GPIO_PORT		GPIOB
 #define WAVETEK_NRF_BUTTON1_PIN			GPIO_PIN_9
 #define WAVETEK_NRF_BUTTON2_PIN			GPIO_PIN_8
 #define WAVETEK_NRF_BUTTON3_PIN			GPIO_PIN_4

 /**
  * Preempt priority configuration
  * User configurable
  */
#define	WAVETEK_NRF_BUTTON1_IT_PREEMPTPRIORITY		3
#define	WAVETEK_NRF_BUTTON2_IT_PREEMPTPRIORITY		3
#define	WAVETEK_NRF_BUTTON3_IT_PREEMPTPRIORITY		3

 /**
  * Sub priority configuration - NOT SUPPORTED ON STM32L0xx
  * User configurable
  */
#define	WAVETEK_NRF_BUTTON1_IT_SUBPRIORITY		0
#define	WAVETEK_NRF_BUTTON2_IT_SUBPRIORITY		0
#define	WAVETEK_NRF_BUTTON3_IT_SUBPRIORITY		0

 /**
  * NVIC interrupt number
  * Fixed configuration depending on the STM32 device used
  */
#define WAVETEK_NRF_BUTTON1_NVIC_VECTOR		EXTI4_15_IRQn	/**< PA9 */
#define WAVETEK_NRF_BUTTON2_NVIC_VECTOR		EXTI4_15_IRQn	/**< PA8 */
#define WAVETEK_NRF_BUTTON3_NVIC_VECTOR		EXTI4_15_IRQn	/**< PB4 */


#ifdef __cplusplus
}
#endif

#endif /* __WAVETEK_NRF_CONF_H */

/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
