/**
  ******************************************************************************
  * @file    main.h
  * @author  MCD Application Team
  * @version V1.0.0
  * @date    01-October-2014
  * @brief   Header for main.c module
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; COPYRIGHT(c) 2014 STMicroelectronics</center></h2>
  *
  * Redistribution and use in source and binary forms, with or without modification,
  * are permitted provided that the following conditions are met:
  *   1. Redistributions of source code must retain the above copyright notice,
  *      this list of conditions and the following disclaimer.
  *   2. Redistributions in binary form must reproduce the above copyright notice,
  *      this list of conditions and the following disclaimer in the documentation
  *      and/or other materials provided with the distribution.
  *   3. Neither the name of STMicroelectronics nor the names of its contributors
  *      may be used to endorse or promote products derived from this software
  *      without specific prior written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
  * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
  * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
  * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
  * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
  * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
  * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  ******************************************************************************
  */


/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __MAIN_H
#define __MAIN_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
	 #include "stdint.h"
/* Exported constants --------------------------------------------------------*/

 /**
  * Number of event that would require sending SD command
  */
#define	EVENT_REQUIRING_SENDING_SD_COMMAND	8

 /**
  * Bit mapping of events
  * There definition below shall not be changed
  */
#define	SD_COMMAND_NOT_ALLOWED	(uint32_t)(~((1<<EVENT_REQUIRING_SENDING_SD_COMMAND)-1))
#define	SD_COMMAND_ALLOWED	(uint32_t)0xFFFFFFFF

/* Exported types ------------------------------------------------------------*/

 /**
  * The enum list shall be in line with the definition of EVENT_REQUIRING_SENDING_SD_COMMAND
  * The first enum which value is below EVENT_REQUIRING_SENDING_SD_COMMAND are allowed to send SD command
  * The enum above or equal to the value of EVENT_REQUIRING_SENDING_SD_COMMAND shall not sent SD command
  *
  * The current firmware implementation supports up to 32 events
  */
 typedef enum
 {
 	eMAIN_Main_HeartRate_Id,
 	eMAIN_Main_Battery_Id,
 	eMAIN_Main_ConnUpdate_Id,
 	eMAIN_Main_Hrs_Evt_Id,
 	eMAIN_Main_ADC_Data_Processing_Id,
 	eMAIN_Main_L2CAP_CID_Register_Id,
 	eMAIN_Main_L2CAP_TX_Packet_Id,
	eMAIN_Main_GAP_Disc_Evt_Id,
 	eMAIN_Main_SD_Command_Resp = EVENT_REQUIRING_SENDING_SD_COMMAND
 } eMAIN_Backround_Task_Id_t;

 typedef void (*pf_Main_UserButtonHandler_t)(void);

/* Exported macros -----------------------------------------------------------*/
/* Exported functions ------------------------------------------------------- */
void TaskExecutionRequest(eMAIN_Backround_Task_Id_t eMAIN_Backround_Task_Id);
void TaskExecuted(eMAIN_Backround_Task_Id_t eMAIN_Backround_Task_Id);
void Background(uint32_t event_mask);
int main(void);


#ifdef __cplusplus
}
#endif

#endif /*__MAIN_H */

/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
